Learn R Programming

tidydp (version 0.1.0)

print.privacy_budget: Print Privacy Budget

Description

Print Privacy Budget

Usage

# S3 method for privacy_budget
print(x, ...)

Value

Returns the privacy budget object invisibly. Called primarily for the side effect of printing budget information to the console, including total epsilon and delta budgets, amounts spent, remaining budget, composition method, and number of operations executed.

Arguments

x

A privacy budget object

...

Additional arguments (unused)