powered by
A tidy-style interface for applying differential privacy to data frames. Provides pipe-friendly functions to add calibrated noise, compute private statistics, and track privacy budgets using the epsilon-delta differential privacy framework.
Maintainer: Thomas Tarler ttarler@gmail.com
Useful links:
https://github.com/ttarler/tidydp
Report bugs at https://github.com/ttarler/tidydp/issues