Print Privacy Budget
# S3 method for privacy_budget
print(x, ...)Returns the privacy budget object invisibly. Called primarily for the side effect of printing budget information to the console, including total epsilon and delta budgets, amounts spent, remaining budget, composition method, and number of operations executed.
A privacy budget object
Additional arguments (unused)